@@ -2,11 +2,8 @@
 context("http")
 
 test_that("GET", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_get("https://eu.httpbin.org/get?q=42")$
+    http_get(http$url("/get", query = list(q = 42)))$
       then(~ rawToChar(.$content))$
       then(~ expect_match(., "\"q\":[ ]*\"42\""))
   })
@@ -14,11 +11,8 @@ test_that("GET", {
 })
 
 test_that("HEAD", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_head("https://eu.httpbin.org")$
+    http_head(http$url("/"))$
       then(function(value) {
         expect_equal(value$status_code, 200)
       })
@@ -27,13 +21,10 @@ test_that("HEAD", {
 })
 
 test_that("headers", {
-
-  skip_if_offline()
-
   xx <- NULL
   do <- async(function() {
     headers = c("X-Header-Test" = "foobar", "X-Another" = "boooyakasha")
-    http_get("https://eu.httpbin.org/headers", headers = headers)$
+    http_get(http$url("/headers"), headers = headers)$
       then(~ jsonlite::fromJSON(rawToChar(.$content), simplifyVector = FALSE))$
       then(function(x) xx <<- x)
   })
@@ -43,20 +34,14 @@ test_that("headers", {
 })
 
 test_that("304 is not an error", {
-
-  skip_if_offline()
-
   do <- async(function() {
-    http_get("https://eu.httpbin.org/status/304")$
+    http_get(http$url("/status/304"))$
       then(http_stop_for_status)
   })
   expect_silent(synchronise(do()))
 })
 
 test_that("http progress bars", {
-
-  skip_if_offline()
-
   xx <- NULL
   totalx <- NULL
   currentx <- 0
@@ -65,7 +50,7 @@ test_that("http progress bars", {
   do <- async(function() {
     on.exit(unlink(tmp, recursive = TRUE), add = TRUE)
     http_get(
-      "https://eu.httpbin.org/image/jpeg",
+      http$url("/image/jpeg"),
       file = tmp <<- tempfile(),
       on_progress = function(data) {
         if (!is.null(data$total)) totalx <<- data$total
@@ -83,8 +68,6 @@ test_that("http progress bars", {
 })
 
 test_that("http progress bar, remove callback", {
-  skip_if_offline()
-
   xx <- NULL
   totalx <- NULL
   currentx <- 0
@@ -97,7 +80,7 @@ test_that("http progress bar, remove callback", {
       if (!is.null(data$current)) currentx <<- data$current
     }
     hx <- http_get(
-      "https://eu.httpbin.org/image/jpeg",
+      http$url("/image/jpeg"),
       file = tmp <<- tempfile(),
       on_progress = progress_callback)
 
@@ -116,9 +99,6 @@ test_that("http progress bar, remove callback", {
 })
 
 test_that("http progress bars & etags", {
-
-  skip_if_offline()
-
   xx <- NULL
   totalx <- NULL
   currentx <- NULL
@@ -128,7 +108,7 @@ test_that("http progress bars & etags", {
   do <- async(function() {
     on.exit(unlink(tmp, recursive = TRUE), add = TRUE)
     http_get(
-      "https://eu.httpbin.org/etag/etag",
+      http$url("/etag/etag"),
       file = tmp,
       headers = c("If-None-Match" = "etag"),
       on_progress = function(data) {
@@ -148,9 +128,11 @@ test_that("http progress bars & etags", {
 
 test_that("progress bar for in-memory data", {
 
-  skip_if_offline()
+  if (packageVersion("presser") <= "1.0.0") {
+    skip("Needs newer presser package")
+  }
 
-  u1 <- "http://eu.httpbin.org/stream-bytes/2048?chunk_size=1024"
+  u1 <- http$url("/stream-bytes/2048", c(chunk_size=1024))
 
   called <- 0L
   bytes <- 0L
@@ -183,13 +165,15 @@ test_that("error, invalid arg", {
 
 test_that("automatic cancellation", {
 
-  skip_if_offline()
+  if (packageVersion("presser") <= "1.0.0") {
+    skip("Needs newer presser package")
+  }
 
   called <- 0L
   do <- function() {
-    r1 <- http_get("https://eu.httpbin.org/delay/5")$
+    r1 <- http_get(http$url("/delay/5"))$
       then(function() called <<- called + 1L)
-    r2 <- http_get("https://eu.httpbin.org/get")$
+    r2 <- http_get(http$url("/get"))$
       then(function() called <<- called + 1L)
     when_any(r1, r2)
   }
@@ -211,10 +195,12 @@ test_that("http_status",  {
 
 test_that("timeout, failed request", {
 
-  skip_if_offline()
+  if (packageVersion("presser") <= "1.0.0") {
+    skip("Needs newer presser package")
+  }
 
   do <- function() {
-    http_get("https://eu.httpbin.org/delay/5", options = list(timeout = 1))
+    http_get(http$url("/delay/5"), options = list(timeout = 1))
   }
 
   tic <- Sys.time()
@@ -239,7 +225,9 @@ test_that("timeout, failed request", {
 
 test_that("more sophisticated timeouts", {
 
-  skip_if_offline()
+  if (packageVersion("presser") <= "1.0.0") {
+    skip("Needs newer presser")
+  }
 
   do <- function() {
     withr::local_options(list(
@@ -247,7 +235,10 @@ test_that("more sophisticated timeouts", {
       async_http_low_speed_time = 2,
       async_http_low_speed_limit = 10
     ))
-    http_get("https://eu.httpbin.org/drip?duration=5&numbytes=10&code=200&delay=0")
+    http_get(http$url(
+      "/drip",
+      c(duration = 5, numbytes = 10, code = 200, delay = 0)
+    ))
   }
 
   tic <- Sys.time()
@@ -260,11 +251,8 @@ test_that("more sophisticated timeouts", {
 })
 
 test_that("errors contain the response", {
-
-  skip_if_offline()
-
   do <- function() {
-    http_get("https://eu.httpbin.org/status/418")$
+    http_get(http$url("/status/418"))$
       then(http_stop_for_status)
   }
 
@@ -275,11 +263,9 @@ test_that("errors contain the response", {
 })
 
 test_that("errors contain the response if 'file' arg given", {
-  skip_if_offline()
-
   tmp <- tempfile()
   do <- function() {
-    http_get("https://eu.httpbin.org/status/418", file = tmp)$
+    http_get(http$url("/status/418"), file = tmp)$
       then(http_stop_for_status)
   }
 
@@ -296,7 +282,7 @@ test_that("http_post", {
 
   do <- function() {
     headers <- c("content-type" = "application/json")
-    http_post("https://eu.httpbin.org/post", data = data, headers = headers)$
+    http_post(http$url("/post"), data = data, headers = headers)$
       then(http_stop_for_status)$
       then(function(x) resp <<- x)
   }
